==> datadog-api-client-2.2.0-sources.jar: com/datadog/api/client/v1/model/SLOType.java <==
/*
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2019-Present Datadog, Inc.
 */

package com.datadog.api.client.v1.model;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.SerializerProvider;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.StdSerializer;
import java.io.IOException;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Objects;
import java.util.Set;

/** The type of the service level objective. */
@JsonSerialize(using = SLOType.SLOTypeSerializer.class)
public class SLOType {

  public static final SLOType METRIC = new SLOType("metric");
  public static final SLOType MONITOR = new SLOType("monitor");

  private static final Set<String> allowedValues =
      new HashSet<String>(Arrays.asList("metric", "monitor"));

  private String value;

  public boolean isValid() {
    return allowedValues.contains(this.value);
  }

  SLOType(String value) {
    this.value = value;
  }

  public static class SLOTypeSerializer extends StdSerializer<SLOType> {
    public SLOTypeSerializer(Class<SLOType> t) {
      super(t);
    }

    public SLOTypeSerializer() {
      this(null);
    }

    @Override
    public void serialize(SLOType value, JsonGenerator jgen, SerializerProvider provider)
        throws IOException, JsonProcessingException {
      jgen.writeObject(value.value);
    }
  }

  @JsonValue
  public String getValue() {
    return this.value;
  }

  public void setValue(String value) {
    this.value = value;
  }

  /** Return true if this SLOType object is equal to o. */
  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    return this.value.equals(((SLOType) o).value);
  }

  @Override
  public int hashCode() {
    return Objects.hash(value);
  }

  @Override
  public String toString() {
    return String.valueOf(value);
  }

  @JsonCreator
  public static SLOType fromValue(String value) {
    return new SLOType(value);
  }
}

==> datadog-api-client-2.24.0-sources.jar: com/datadog/api/client/v1/model/SLOType.java <==
/*
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2019-Present Datadog, Inc.
 */

package com.datadog.api.client.v1.model;

import com.datadog.api.client.ModelEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.SerializerProvider;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.StdSerializer;
import java.io.IOException;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;

/** The type of the service level objective. */
@JsonSerialize(using = SLOType.SLOTypeSerializer.class)
public class SLOType extends ModelEnum<String> {

  private static final Set<String> allowedValues =
      new HashSet<String>(Arrays.asList("metric", "monitor", "time_slice"));

  public static final SLOType METRIC = new SLOType("metric");
  public static final SLOType MONITOR = new SLOType("monitor");
  public static final SLOType TIME_SLICE = new SLOType("time_slice");

  SLOType(String value) {
    super(value, allowedValues);
  }

  public static class SLOTypeSerializer extends StdSerializer<SLOType> {
    public SLOTypeSerializer(Class<SLOType> t) {
      super(t);
    }

    public SLOTypeSerializer() {
      this(null);
    }

    @Override
    public void serialize(SLOType value, JsonGenerator jgen, SerializerProvider provider)
        throws IOException, JsonProcessingException {
      jgen.writeObject(value.value);
    }
  }

  @JsonCreator
  public static SLOType fromValue(String value) {
    return new SLOType(value);
  }
}
